@@ -14,42 +14,12 @@ def max_frets_on_screen(limit=24):
 
 class PluckedString(object):
 
-    def __init__(self, tone, alt='', oct=0, frets=0, display=None, verbose=1):
-        self.__key = None
-        self.tuning = Note(tone, alt, oct)
-        self.display_method = display
+    def __init__(self, c, alt='', oct=3, frets=0, display=None, verbose=1):
+        self.tuning = Note(c, alt, oct)
+        self.display_mode = display
         self.frets = 12 if not frets else frets
         self.verbose = verbose
  
-
-    @property
-    def key(self):
-        ''' inits an object of parent Key class from self.display_method '''
-        if not self.__key:
-            __key  = self.display_method.__self__
-            Key = __key.__class__
-            self.__key = Key(
-                __key.root.chr,
-                __key.root.alt,
-            )
-        return self.__key
-
-    # USERS DO NOT SET STRING.KEY... USE STRING.DISPLAY_METHOD
-    # @key.setter
-    # def key(self, k):
-    #     self.__key = k
-
-    @property
-    def display_method(self):
-        if not self.__display:
-            self.__display = ChromaticKey(*self.tuning).scale
-        return self.__display
-
-    @display_method.setter
-    def display_method(self, dm):
-        self.__display = dm
-
-
     @property
     def frets(self):
         return self.__frets
@@ -63,8 +33,10 @@ class PluckedString(object):
         ''' prints string notes matching given key '''
         string_line = Row()
 
+        mode = self.display_mode if self.display_mode else ChromaticScale(*self.tuning)
+
         for fret_n, note in enumerate(
-            self.display_method(
+            mode.spell(
                 note_count=self.frets,
                 start_note=self.tuning,
                 yield_all=True,
@@ -73,7 +45,7 @@ class PluckedString(object):
 
             fret_value = ''
             if note:
-                note_fg = 'green' if note ** self.key.root else 'magenta'
+                note_fg = 'green' if note ** mode.root else 'magenta'
                 fret_value = '{}{}{}'.format(
                     FString(note.chr, size=1, fg=note_fg, fx=['']),
                     FString(note.repr_alt, size=0, fg=note_fg, fx=['']),
@@ -112,49 +84,11 @@ class PluckedString(object):
 
 class PluckedStringInstrument(object):
 
-    def __init__(self, *notes, name=''):
-        self.name = name
-        self.strings = [ PluckedString(*n) for n in notes ]
-
-
-    def string(self, s):
-        return self.strings[s -1]
-
-
-    def fretboard(self, display=None, frets=12, verbose=1, limit=24):
-
-        if frets > limit:
-            frets = limit
-
-        # INIT A NEW SCALE, OTHERWISE YOU USE THE SAME OUTER OBJECT!!!
-        if verbose:
-            echo(self.fret_inlays(verbose=verbose, frets=frets))
-
-        echo(self.render_binding('upper', frets=frets))
-
-        for string in self.strings:
-
-            # string numbers
-            string_n = FString(
-                self.strings.index(string) +1,
-                fg='cyan', 
-                fx=['faint' if verbose < 1 else ''],
-            )
-
-            string.display_method = display
-            string.frets = frets
-            string.verbose = verbose
-
-            echo(str(string_n) + str(string))
-        
-        echo(self.render_binding('lower', frets=frets))
-
-
     @classmethod
-    def fret_inlays(cls, verbose=1, frets=12):
+    def render_inlays(cls, frets=12, verbose=1):
 
         if not verbose:
-            return ''
+            return
 
         inlays = (
             '',
@@ -209,38 +143,21 @@ class PluckedStringInstrument(object):
             frets -= 1
             i += 1
 
-        return inlay_row
+        echo(inlay_row)
 
 
     @staticmethod
     def render_binding(side, frets=12):
-        # https://en.wikipedia.org/wiki/Box-drawing_character
-        normal = {
-            'upper': '═',
-            'lower': '═'
-        }
-        twelve = {
-            'upper': '╦',
-            'lower': '╩'
-        }
-        joints = {
-            'upper': '╤',
-            'lower': '╧'
-        }
-        capo = {
-            'upper': '     ╔',
-            'lower': '     ╚',
-        }
-        final = {
-            'upper': '╕',
-            'lower': '╛',
-        }
-        fine = {
-            'upper': '╗',
-            'lower': '╝',
-        }
+        ''' https://en.wikipedia.org/wiki/Box-drawing_character
+        '''
+        normal = { 'upper': '═', 'lower': '═' }
+        twelve = { 'upper': '╦', 'lower': '╩' }
+        joints = { 'upper': '╤', 'lower': '╧' }
+        capo   = { 'upper': '╔', 'lower': '╚' }
+        final  = { 'upper': '╕', 'lower': '╛' }
+        fine   = { 'upper': '╗', 'lower': '╝' }
         total_fret_width = _NOTE_WIDTH + _FRET_WIDTH
-        fret_bind = capo[side]
+        fret_bind = ' ' * _NOTE_WIDTH + capo[side]
         for f in range(1, frets * total_fret_width + 1):
             # final fret
             if f == frets * total_fret_width:
@@ -257,4 +174,36 @@ class PluckedStringInstrument(object):
             # normal bind
             else:
                 fret_bind += normal[side]
-        return fret_bind
+        
+        echo(fret_bind)
+
+
+    def __init__(self, *notes, name=''):
+        self.strings = [ PluckedString(*n) for n in notes ]
+        self.name = name
+
+    def render_string(self, s, display, frets=12, verbose=1):
+        if not s:
+            return
+
+        string_n = FString(
+            s,
+            fg='cyan', 
+            fx=['faint' if verbose < 1 else ''],
+        )
+
+        string = self.strings[s-1]
+        # INIT A NEW SCALE, OTHERWISE YOU USE THE SAME OUTER OBJECT!!!
+        string.display_mode = display
+        string.frets = frets
+        string.verbose = verbose
+
+        echo(string_n + string)
+
+    def render_fretboard(self, display=None, frets=12, verbose=1, limit=24):
+        if frets > limit: frets = limit
+        self.render_inlays(frets, verbose)
+        self.render_binding('upper', frets)
+        for s, _ in enumerate(self.strings):
+            self.render_string(s+1, display, frets, verbose)
+        self.render_binding('lower', frets)
