@@ -1,14 +1,7 @@
 from bestia.iterate import LoopedList
-from bestia.output import echo
 
 from .errors import *
 
-SHARP = 1
-FLAT = -1
-
-TONE = 2
-SEMITONE = 1
-
 UNISON = 0
 DIMINISHED_SECOND = 0
 
@@ -87,6 +80,9 @@ _OCTS = (
     '⁹',
 )
 
+MAX_OCT = 9
+
+
 _ALTS = {
     'bb': '𝄫',
     'b': '♭',
@@ -101,10 +97,17 @@ def input_alterations():
 def output_alterations():
     return list(_ALTS.values())
 
+
 class Note(object):
 
     def __init__(self, char, *args):
-
+        ''' init WITHOUT specifying argument names
+            should be able to handle:
+            Note('C')
+            Note('C', 3)
+            Note('C', '#')
+            Note('C', '#', 3)
+        '''
         self.chr = char.upper()
         if self.chr not in _CHARS:
             raise InvalidNote(char)
@@ -115,23 +118,10 @@ class Note(object):
         if len(args) >  2:
             raise InvalidNote('Too many arguments')
 
-        if len(args) == 2:
-            if args[0] in input_alterations():
-                self.alt = args[0]
-            else:
-                raise InvalidAlteration(args[0])
-
-            try:
-                self.oct = int(args[1])
-
-            except:
-                raise InvalidOctave(args[1])
-
+        # with only 1 arg, decide if it's alt or oct
         if len(args) == 1:
-
             if args[0] in input_alterations():
                 self.alt = args[0]
-
             else:
                 try:
                     self.oct = int(args[0])
@@ -140,6 +130,19 @@ class Note(object):
                         'Failed to parse argument: '.format(args[0])
                     )
 
+        # with 2 args, order must be alt, oct
+        if len(args) == 2:
+            if args[0] not in input_alterations():
+                raise InvalidAlteration(args[0])
+            self.alt = args[0]
+
+            try:
+                self.oct = int(args[1])
+            except:
+                raise InvalidOctave(args[1])
+
+        if self.oct > MAX_OCT:
+            raise InvalidOctave(self.oct)
 
 
     def __iter__(self):
@@ -147,7 +150,6 @@ class Note(object):
         for i in (self.chr, self.alt, self.oct):
             yield i
 
-
     def __repr__(self):
         return '{}{}{}'.format(
             self.chr,
@@ -168,68 +170,57 @@ class Note(object):
 
     def __sub__(self, other):
         if self.__class__ == other.__class__:
-            return self.__interval_from(other)
-        raise TypeError('unsupported operand type(s) for -')
+            oct_interval = (self.oct - other.oct) * OCTAVE
+            chr_interval = _CHARS.index(self.chr) - _CHARS.index(other.chr)
+            alt_interval = input_alterations().index(self.alt) - input_alterations().index(other.alt)
+            return oct_interval + chr_interval + alt_interval
+        raise TypeError(f' - not supported with {other.__class__}')
 
-
-    # OLD is_a(oct=None)
     def __pow__(self, other):
-        ''' **  operator implements LOOSEST equality '''
         if self.__class__ == other.__class__:
             if self.chr == other.chr:
                 if self.alt == other.alt:
                     return True
             return False
-        raise TypeError('unsupported operand type(s) for **')
-
-
-    # OLD ==
-    def __lshift__(self, other):
-        ''' << operator implements LOOSE equality (enharmony) '''
-        if self.__class__ == other.__class__:
-            return self.__interval_from(other) == 0
-        raise TypeError('unsupported operand type(s) for <<')
+        raise TypeError(f' ** not supported with {other.__class__}')
 
     def __rshift__(self, other):
-        ''' >> operator implements LOOSE equality (enharmony) '''
-        if other.__class__ == self.__class__:
-            return other.__interval_from(self) == 0
-        raise TypeError('unsupported operand type(s) for >>')
-
-
-    # OLD is_a(oct=1)
-    def __eq__(self, other):
-        ''' == operator implements STRICT equality '''
         if self.__class__ == other.__class__:
             if self.chr == other.chr:
                 if self.alt == other.alt:
                     if self.oct == other.oct:
                         return True
+            return False
+        raise TypeError(f' >> not supported with {other.__class__}')
+
+
+    def __eq__(self, other):  # ==
+        if other.__class__ == self.__class__:
+            return other - self == UNISON
 
     def __ne__(self, other):  # !=
-        # THIS IS A PROBLEM, IT SHOULD BE DIRECT OPPOSITE TO __EQ__
-        if self.__class__ != other.__class__:
-            return True
-        return self.__interval_from(other) != 0
+        if other.__class__ == self.__class__:
+            return other - self != UNISON
+        return True
 
     def __gt__(self, other):  # >
         if self.__class__ == other.__class__:
-            return self.__interval_from(other) > 0
+            return self - other > UNISON
         raise TypeError(f' > not supported with {other.__class__}')
 
     def __ge__(self, other):  # >=
         if self.__class__ == other.__class__:
-            return self.__interval_from(other) >= 0
+            return self - other >= UNISON
         raise TypeError(f' >= not supported with {other.__class__}')
 
     def __lt__(self, other):  # <
         if self.__class__ == other.__class__:
-            return self.__interval_from(other) < 0
+            return self - other < UNISON
         raise TypeError(f' < not supported with {other.__class__}')
 
     def __le__(self, other):  # <=
         if self.__class__ == other.__class__:
-            return self.__interval_from(other) <= 0
+            return self - other <= UNISON
         raise TypeError(f' <= not supported with {other.__class__}')
 
 
@@ -243,33 +234,24 @@ class Note(object):
             negative fails...
         '''
         c = ''
-        count = 0
         i = 1
-
-        while count != n:
+        while n != 0:
             c = self.relative_chr(i)
             if c:
-                count += 1
+                n -= 1
             i += 1
-
         return c
 
     ### OCT METHODS
     def oversteps_oct(self, other):
-        ''' does NOT take oct attr into account '''
+        ''' evaluates whether I need to cross octave border in rder to go from self to other
+            ignores octave
+        '''
         if self.chr != other.chr:
             return _CHARS.index(self.chr) > _CHARS.index(other.chr)
         return input_alterations().index(self.alt) > input_alterations().index(other.alt)
 
 
-    def __interval_from(self, other):
-        ''' used ONLY to implement comparison operators, do NOT call directly... '''
-        oct_interval = (self.oct - other.oct) * OCTAVE
-        chr_interval = _CHARS.index(self.chr) - _CHARS.index(other.chr)
-        alt_interval = input_alterations().index(self.alt) - input_alterations().index(other.alt)
-        return oct_interval + chr_interval + alt_interval
-
-
     # ENHARMONIC ATTRIBUTES
     @property
     def enharmonic_row(self):
@@ -279,16 +261,15 @@ class Note(object):
     def matrix_coordinates(self):
         for row_index, row in enumerate(EnharmonicMatrix):
             for note_index, enharmonic_note in enumerate(row):
-                if self ** enharmonic_note:
+                if self ** enharmonic_note:  # ignore oct
                     return (row_index, note_index)
 
 
-
 ### This is the heart of the whole project
 ### indeces are used to determine:
 ###   * when to change octs
 ###   * intervals between Note instances
-### notes MUST be unique so that Note.degree() finds 1 exact match!
+### notes MUST be unique so that MusicKey[d] finds 1 exact match!
 EnharmonicMatrix = LoopedList(
 
     ## 2-octave enharmonic relationships
